@@ -1,7 +1,7 @@
 #!perl -w
 use strict;
 use Test;
-BEGIN { plan tests => 19 }
+BEGIN { plan tests => 18 }
 
 if (1) {
    print "\nRequired modules:\n";
@@ -23,7 +23,7 @@ if (1) {
 
 if (1 && $^O eq 'MSWin32') {
    print "\nWin32 modules, dependent on features used:\n";
-   foreach my $m ('Win32','Win32::API','Win32API::Net','Win32::TieRegistry') {
+   foreach my $m ('Win32','Win32::API','Win32::TieRegistry') {
      print "use $m\t";
      ok(eval("use $m; 'ok'"), 'ok');
      # skip(!eval("use $m; 1"), 1);
